@@ -6,6 +6,7 @@ from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
 from bitmovin_api_sdk.common.poscheck import poscheck_except
 from bitmovin_api_sdk.encoding.infrastructure.kubernetes.kubernetes_api import KubernetesApi
 from bitmovin_api_sdk.encoding.infrastructure.aws.aws_api import AwsApi
+from bitmovin_api_sdk.encoding.infrastructure.static_ips.static_ips_api import StaticIpsApi
 from bitmovin_api_sdk.encoding.infrastructure.azure.azure_api import AzureApi
 from bitmovin_api_sdk.encoding.infrastructure.gce.gce_api import GceApi
 from bitmovin_api_sdk.encoding.infrastructure.prewarmed_encoder_pools.prewarmed_encoder_pools_api import PrewarmedEncoderPoolsApi
@@ -37,6 +38,13 @@ class InfrastructureApi(BaseApi):
             logger=logger
         )
 
+        self.static_ips = StaticIpsApi(
+            api_key=api_key,
+            tenant_org_id=tenant_org_id,
+            base_url=base_url,
+            logger=logger
+        )
+
         self.azure = AzureApi(
             api_key=api_key,
             tenant_org_id=tenant_org_id,
